Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/ltr390_simpletest.py
    :caption: examples/ltr390_simpletest.py
    :linenos:

Configuration example
-----------------------------

Adjust the configuration options for the sensor

.. literalinclude:: ../examples/ltr390_configuration_example.py
    :caption: examples/ltr390_configuration_example.py
    :linenos:

Measurement threshold example
-----------------------------

Be alerted when the measured value passes a high or low threshold

.. literalinclude:: ../examples/ltr390_alert_test.py
    :caption: examples/ltr390_alert_test.py
    :linenos:
